<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>ScrobblerFactory</name>
    <message>
        <location filename="../scrobblerfactory.cpp" line="31"/>
        <source>Scrobbler Plugin</source>
        <translation>Scrobbler 插件</translation>
    </message>
    <message>
        <location filename="../scrobblerfactory.cpp" line="51"/>
        <source>About Scrobbler Plugin</source>
        <translation>关于 Scrobbler 插件</translation>
    </message>
    <message>
        <location filename="../scrobblerfactory.cpp" line="52"/>
        <source>Qmmp AudioScrobbler Plugin</source>
        <translation>Qmmp Scrobbler 插件</translation>
    </message>
    <message>
        <location filename="../scrobblerfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Scrobbler Plugin Settings</source>
        <translation>Scrobbler 插件设置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="20"/>
        <source>Last.fm</source>
        <translation>Last.fm</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="31"/>
        <location filename="../settingsdialog.ui" line="104"/>
        <source>Session:</source>
        <translation>会议：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>Check</source>
        <translation>检查</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <location filename="../settingsdialog.ui" line="95"/>
        <source>Register new session</source>
        <translation>注册新会议</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="73"/>
        <source>Libre.fm</source>
        <translation>Libre.fm</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="106"/>
        <location filename="../settingsdialog.cpp" line="132"/>
        <location filename="../settingsdialog.cpp" line="183"/>
        <source>Message</source>
        <translation>信息</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="107"/>
        <source>1. Wait for browser startup</source>
        <translation>1.等候浏览器启动</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="108"/>
        <source>2. Allow Qmmp to scrobble tracks to your %1 account</source>
        <translation>2.允许Qmmp向您的%1账户推荐类似曲目</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="109"/>
        <source>3. Press &quot;OK&quot;</source>
        <translation>3.按“OK”</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="114"/>
        <location filename="../settingsdialog.cpp" line="118"/>
        <location filename="../settingsdialog.cpp" line="147"/>
        <location filename="../settingsdialog.cpp" line="151"/>
        <location filename="../settingsdialog.cpp" line="191"/>
        <location filename="../settingsdialog.cpp" line="195"/>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="114"/>
        <location filename="../settingsdialog.cpp" line="147"/>
        <location filename="../settingsdialog.cpp" line="191"/>
        <source>Network error</source>
        <translation>网络错误</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="118"/>
        <location filename="../settingsdialog.cpp" line="151"/>
        <source>Unable to register new session</source>
        <translation>无法注册新会话</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="132"/>
        <source>New session has been received successfully</source>
        <translation>新会话已被成功接收</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="183"/>
        <source>Permission granted</source>
        <translation>权限已授予</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="195"/>
        <source>Permission denied</source>
        <translation>权限被拒绝</translation>
    </message>
</context>
</TS>
